Index class

Constructors

Index({required List list})

Properties

hashCode int
The hash code for this object.
no setterinherited
len int
no setter
list List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
no setter

Methods

dicrease() → void
increase() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
random() → void
setIndex(int index) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited