EasyAudioPlayers class
Constructors
- EasyAudioPlayers.getEmptyInstance()
-
factory
- EasyAudioPlayers.getInstanceWithReRender(dynamic reRenderUICallback())
-
factory
-
EasyAudioPlayers.setMusicList(List<
Music> musicList, [String listName = "", dynamic reRenderUICallback()?]) -
factory
Properties
- currentMusic → Music
-
no setter
- currentSeconds → double
-
no setter
- durationSeconds → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMusicFirstPlayExecuted → bool
-
no setter
- isPlaying → bool
-
no setter
- listName → String
-
no setter
-
musicList
→ List<
Music> -
no setter
- musicMode → MusicMode
-
no setter
- nowVolume → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
changeVolume(
int volume) → void -
moveMusicList(
Transition transition) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void -
resume(
) → void -
seek(
double newCurrenrSeconds) → void -
start(
int listIndex) → void -
toggleMusicMode(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited